@@ -9,7 +9,6 @@ import json
 import re
 
 from texta_tools.text_processor import TextProcessor
-from texta_tools.embedding import Embedding
 from typing import List, Union
 from .pipeline import get_pipeline_builder
 from .tagging_report import TaggingReport
@@ -28,14 +27,18 @@ def check_model_loaded(func):
     return func_wrapper
 
 
+
 class Tagger:
 
     pipeline = get_pipeline_builder()
     CLASSIFIERS = pipeline.get_classifier_options()
     VECTORIZERS = pipeline.get_extractor_options()
+    ANALYZERS = pipeline.get_analyzer_options()
+    TOKENIZERS = pipeline.get_tokenizer_options()
 
     def __init__(self, workers=1, description="Tagger", embedding=None, mlp=None, custom_stop_words=[], ignore_numbers=False, ignore_punctuation=True,
-                 test_size=0.2, classifier=CLASSIFIERS[0], vectorizer=VECTORIZERS[0], max_examples_per_class=10000, feature_hashing=False):
+                 test_size=0.2, classifier=CLASSIFIERS[0], vectorizer=VECTORIZERS[0], max_examples_per_class=10000, feature_hashing=False,
+                 analyzer=ANALYZERS[0], tokenizer=TOKENIZERS[0]):
         # resulting objects etc.
         self.model = None
         self.report = None
@@ -43,6 +46,8 @@ class Tagger:
         # options
         self.classifier = classifier
         self.vectorizer = vectorizer
+        self.analyzer = analyzer
+        self.tokenizer = tokenizer
         self.workers = workers
         self.test_size = test_size
         self.description = description
@@ -51,7 +56,7 @@ class Tagger:
 
         # check embedding for phraser
         phraser = None
-        if isinstance(embedding, Embedding):
+        if embedding:
             phraser = embedding.phraser
         
         # set text processor
@@ -167,7 +172,7 @@ class Tagger:
         scorer = self._get_scorer(scoring, pos_label, sklearn_average)
         # pipeline
         pipe_builder = get_pipeline_builder(workers=self.workers)
-        pipe_builder.set_pipeline_options(self.vectorizer, self.classifier)
+        pipe_builder.set_pipeline_options(self.vectorizer, self.classifier, self.analyzer, self.tokenizer)
         c_pipe, c_params = pipe_builder.build(fields=field_list)
         # build data map
         data_sample_x_map = {}
